==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: zh_CN\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  ""

]
, "Groups"
: "组"

, "Roles"
: "角色"

, "Applications"
: "应用程序"

, "Containers"
: ""

, "Shared Tags"
: "共享的标签"

, "Customfields"
: ""

, "Computers"
: "电脑"

, "Access Log, Access Logs"
: [
  ""

]
, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "Admin"
: "管理"

, "Refresh"
: ""

, "Name"
: "名字"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "电脑"

]
, "Default Addressbook for new contacts and groups"
: ""

, "Group, Groups"
: [
  ""

]
, "Application, Applications"
: [
  ""

]
, "Config, Configs"
: [
  ""

]
, "Configs"
: ""

, "Please wait"
: "请稍等"

, "Updating Memberships"
: "更新会员身份"

, "Failed"
: "失败"

, "Could not save group."
: "不能保存组"

, "Errors"
: "错误"

, "Please fix the errors noted."
: "请修复标明的错误"

, "Group Name"
: "组名"

, "Description"
: "描述"

, "Visibility"
: "可见度"

, "Display in addressbook"
: "在地址本中显示"

, "Hide from addressbook"
: "从地址本中隐藏"

, "Saved in Addressbook"
: ""

, "Group Members"
: "组成员"

, "Transferring {0}..."
: ""

, "Add new group"
: "添加新组"

, "Edit Group \"{0}\""
: "编辑组\"{0}\""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0}设置"

, "enable application"
: "启用程序"

, "disable application"
: "关闭程序"

, "settings"
: "设置"

, "Search:"
: "搜索："

, "disabled"
: "关闭的"

, "enabled"
: "启用的"

, "unknown status ({0})"
: "未知状态({0})"

, "Displaying application {0} - {1} of {2}"
: "显示程序 {0} - {1} of {2}"

, "No applications to display"
: "没有程序要显示"

, "Order"
: ""

, "Status"
: "状态"

, "Version"
: ""

, "Confirm"
: "确认"

, "Do you really want to delete the selected groups?"
: "真的要删除选中的组？"

, "Deleting group(s)..."
: "删除组..."

, "Some error occurred while trying to delete the group."
: "当试图删除组时发生错误"

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "显示组 {0} - {1} of {2}"

, "No groups to display"
: "没有组要显示"

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "电脑名"

, "IP Address"
: "IP 地址"

, "Login Time"
: "登录时间"

, "Logout Time"
: "登出时间"

, "Client Type"
: ""

, "Session ID"
: "会话 ID"

, "Login Name"
: "登录名"

, "Result"
: "结果"

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "无效的密码"

, "ambiguous username"
: "不清楚的用户名"

, "user not found"
: "没有发现用户"

, "failure"
: "失败"

, "success"
: "成功"

, "Could not save role."
: "不能保存角色"

, "Deleting role..."
: "删除角色..."

, "Some error occurred while trying to delete the role."
: "当试图删除角色是发生错误"

, "Rights"
: "权限"

, "Members"
: "成员"

, "Role Name"
: "角色名"

, "Role"
: ""

, "Add New Role"
: "添加新角色"

, "Edit Role \"{0}\""
: "编辑角色 \"{0}\""

, "Container Name"
: ""

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  ""

]
, "Model"
: ""

, "personal"
: ""

, "shared"
: ""

, "Color"
: "颜色"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Do you really want to delete the selected roles?"
: "真的想删除选中的角色？"

, "Deleting role(s)..."
: "删除角色 ..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "显示角色{0} - {1} of {2}"

, "No roles to display"
: "没有角色要显示"

, "Do you really want to delete the selected tags?"
: "真的想删除选中的标签？"

, "Deleting tag(s)..."
: "删除标签"

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "显示标签{0} - {1} of {2}"

, "No tags to display"
: "没有标签要显示"

, "Usage:&#160;"
: ""

, "Label"
: ""

, "Value"
: ""

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "取消"

, "OK"
: ""

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "姓"

, "First name"
: "名"

, "Email"
: "电子邮件"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "开放 ID"

, "Last login at"
: "上次登录时间"

, "Last login from"
: "上次登录于"

, "Password changed"
: "密码已修改"

, "Expires"
: "过期"

, "Set new password"
: "设置新密码"

, "Please enter the new password:"
: "请输入新密码"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Samba 用户"

]
, "Email User, Email Users"
: [
  "电子邮件用户"

]
, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: "基本组"

, "Unix"
: "Unix"

, "Home Directory"
: "Home 目录"

, "Login Shell"
: "登录 Shell"

, "Windows"
: "视窗"

, "Home Drive"
: "Home 盘"

, "Logon Time"
: ""

, "never logged in"
: "从未登录"

, "Home Path"
: "Home 路径"

, "Logoff Time"
: ""

, "never logged off"
: "从未登出"

, "Profile Path"
: "Profile 路径"

, "Password Last Set"
: "最后密码设置"

, "never"
: "从不"

, "Logon Script"
: "登录脚本"

, "Password Can Change"
: "密码可以修改"

, "not set"
: "没设置"

, "Password Must Change"
: "密码必须修改"

, "Kick Off Time"
: "开始时间"

, "Filesystem Quota"
: ""

, "Quota"
: "额度"

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "信息"

, "Last Login"
: "上次登录"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: "电子邮件别名"

, "Add an alias address..."
: "添加别名地址..."

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: "转发电子邮件"

, "Add a forward address..."
: "添加转发地址..."

, "Forward Only"
: "只转发"

, "Password confirmation"
: "密码确认"

, "Repeat password"
: "再输一遍密码"

, "Ok"
: "确认"

, "Account"
: "账户"

, "Password"
: "密码"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: "不知道"

, "Password set"
: "密码设置"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "文件服务器"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: "更新标签..."

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "允许的上下文"

, "Context"
: "上下文"

, "Account Rights"
: "账户权限"

, "View"
: "视图"

, "Use"
: "使用"

, "Tag Name"
: "标签名"

, "Tag"
: ""

, "Add New Tag"
: "添加新标签"

, "Edit Tag \"{0}\""
: "编辑标签\"{0}\""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "管理访问日志"

, "delete access log entries"
: "删除访问日志记录"

, "manage accounts"
: "管理帐户"

, "add and edit users and groups, add group members, change user passwords"
: "添加并编辑用户和组，添加组成员，修改用户密码"

, "manage applications"
: "管理应用程序"

, "enable and disable applications, edit application settings"
: "开启和关闭应用程序，编辑应用程序设置"

, "manage roles"
: "管理角色"

, "add and edit roles, add new members to roles, add application rights to roles"
: "添加并编辑角色，给角色添加新成员，给角色添加应用程序权限"

, "manage shared tags"
: "管理共享的标签"

, "add, delete and edit shared tags"
: "添加、删除和编辑共享的标签"

, "manage computers"
: "管理电脑"

, "add, delete and edit (samba) computers"
: "添加、删除和编辑（samba）电脑"

, "manage containers"
: ""

, "add, delete and edit containers and manage container grants"
: ""

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "浏览访问日志"

, "view access log list"
: "浏览访问日志列表"

, "view accounts"
: "浏览帐户"

, "view accounts list and details"
: "浏览帐户列表和细节"

, "view applications"
: "浏览应用程序"

, "view applications list and details"
: "浏览应用程序列表和细节"

, "view roles"
: "浏览角色"

, "view roles list and details"
: "浏览角色列表和细节"

, "view computers"
: "浏览电脑"

, "view computers list and details"
: "浏览电脑列表和细节"

, "view containers"
: ""

, "view personal and shared containers"
: ""

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Could not save tag without (view-)rights"
: ""

, "User"
: ""

, "Access Log"
: ""

, "Computer"
: "电脑"

, "Group"
: ""

, "Application"
: ""

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Samba User"
: "Samba 用户"

, "Email User"
: "电子邮件用户"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Admin/js/Admin-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0}设置"

, "Search:"
: "搜索："

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "显示程序 {0} - {1} of {2}"

, "No applications to display"
: "没有程序要显示"

, "Order"
: ""

, "Name"
: "名字"

, "Status"
: "状态"

, "Version"
: ""

, "Confirm"
: "确认"

, "Do you really want to delete the selected groups?"
: "真的要删除选中的组？"

, "Deleting group(s)..."
: "删除组..."

, "Failed"
: "失败"

, "Some error occurred while trying to delete the group."
: "当试图删除组时发生错误"

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "显示组 {0} - {1} of {2}"

, "No groups to display"
: "没有组要显示"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "描述"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "错误"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "取消"

, "OK"
: ""

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""

]
, "Value"
: ""

, "Default ({0})"
: ""

, "Computer Name"
: "电脑名"

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: "请稍等"

, "Updating Tag"
: "更新标签..."

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "请修复标明的错误"

, "Allowed Contexts"
: "允许的上下文"

, "Context"
: "上下文"

, "Account Rights"
: "账户权限"

, "View"
: "视图"

, "Use"
: "使用"

, "Tag Name"
: "标签名"

, "Color"
: "颜色"

, "Transferring {0}..."
: ""

, "Tag"
: ""

, "Add New Tag"
: "添加新标签"

, "Edit Tag \"{0}\""
: "编辑标签\"{0}\""

, "Do you really want to delete the selected tags?"
: "真的想删除选中的标签？"

, "Deleting tag(s)..."
: "删除标签"

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "显示标签{0} - {1} of {2}"

, "No tags to display"
: "没有标签要显示"

, "Usage:&#160;"
: ""

, "Updating Memberships"
: "更新会员身份"

, "Could not save role."
: "不能保存角色"

, "Deleting role..."
: "删除角色..."

, "Some error occurred while trying to delete the role."
: "当试图删除角色是发生错误"

, "Rights"
: "权限"

, "Members"
: "成员"

, "Role Name"
: "角色名"

, "Role"
: ""

, "Add New Role"
: "添加新角色"

, "Edit Role \"{0}\""
: "编辑角色 \"{0}\""

, "Do you really want to delete the selected roles?"
: "真的想删除选中的角色？"

, "Deleting role(s)..."
: "删除角色 ..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "显示角色{0} - {1} of {2}"

, "No roles to display"
: "没有角色要显示"

, "Access Log, Access Logs"
: [
  ""

]
, "Groups"
: "组"

, "Applications"
: "应用程序"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: "基本组"

, "Unix"
: "Unix"

, "Home Directory"
: "Home 目录"

, "Login Shell"
: "登录 Shell"

, "Windows"
: "视窗"

, "Home Drive"
: "Home 盘"

, "Login Time"
: "登录时间"

, "never logged in"
: "从未登录"

, "Home Path"
: "Home 路径"

, "Logout Time"
: "登出时间"

, "never logged off"
: "从未登出"

, "Profile Path"
: "Profile 路径"

, "Password Last Set"
: "最后密码设置"

, "never"
: "从不"

, "Logon Script"
: "登录脚本"

, "Password Can Change"
: "密码可以修改"

, "not set"
: "没设置"

, "Password Must Change"
: "密码必须修改"

, "Kick Off Time"
: "开始时间"

, "Filesystem Quota"
: ""

, "Quota"
: "额度"

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "信息"

, "Last Login"
: "上次登录"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "添加别名地址..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "只转发"

, "Password confirmation"
: "密码确认"

, "Repeat password"
: "再输一遍密码"

, "Ok"
: "确认"

, "Account"
: "账户"

, "First name"
: "名"

, "Last name"
: "姓"

, "Login name"
: ""

, "Password"
: "密码"

, "OpenID"
: "开放 ID"

, "enabled"
: "启用的"

, "disabled"
: "关闭的"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "过期"

, "Visibility"
: "可见度"

, "Display in addressbook"
: "在地址本中显示"

, "Hide from addressbook"
: "从地址本中隐藏"

, "Saved in Addressbook"
: ""

, "Last login at"
: "上次登录时间"

, "don't know"
: "不知道"

, "Last login from"
: "上次登录于"

, "Password set"
: "密码设置"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "文件服务器"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  ""

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Samba 用户"

]
, "Email User, Email Users"
: [
  "电子邮件用户"

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "密码已修改"

, "Set new password"
: "设置新密码"

, "Please enter the new password:"
: "请输入新密码"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "组名"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "组成员"

, "personal"
: ""

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  "电脑"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "角色"

, "Containers"
: ""

, "Shared Tags"
: "共享的标签"

, "Customfields"
: ""

, "Computers"
: "电脑"

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "管理"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP 地址"

, "Client Type"
: ""

, "Session ID"
: "会话 ID"

, "Login Name"
: "登录名"

, "Result"
: "结果"

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "无效的密码"

, "ambiguous username"
: "不清楚的用户名"

, "user not found"
: "没有发现用户"

, "failure"
: "失败"

, "success"
: "成功"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""


































, "Application"
: ""

, "Group"
: ""

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: ""

, "Samba User"
: "Samba 用户"

, "Email User"
: "电子邮件用户"

, "Container"
: ""

, "Computer"
: "电脑"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
